/*
 *  Header file describes basic functions and structures to allow your
 *  programs to play .RAD files directly via sound card with Adlib support!
 *
 */


/*
 * The function belove processes basic initializations of allocated memory
 * module and loaded .RAD file in it. The parameter is a selector to allocated
 * memory block which computes as follow: Sel=(USHORT)(FLATPOINTER >> 16),
 * where FLATPOINTER is a result of DosAllocMem() system call.
 * CAUTION: Don't forget to COMMIT allocated memory block befor use.
 */
extern _Far16 _Pascal initplayer(USHORT Sel);

/*
 * This function is used to do the actual playing. It must be called 50 or
 * 18.2 times a second (depends on bit 6 at offset 17 in .RAD file. If bit is
 * set so it is a "slow playing" module with 18.2Hz frequency). The Sel parameter
 * must be point to already initialized (by initplayer()) memory block.
 */
extern _Far16 _Pascal playmusic(USHORT Sel);

/*
 * Is used to shutup any sounds out of adlib after module played.
 */
extern _Far16 _Pascal endplayer(void);

/*
 * The following structure describes the memory block. It must be mansioned
 * that is has static size in 0xE0C9 bytes! Using the structure fields is
 * possible after initplayer() called.
 */
struct FM_MODULE {
	char	buffer[0xe000];	/* Buffer where .RAD file placed	*/
	char	hmm0[10];
	char	InstPtrs[62];	/* offsets of instrument data		*/
	char	hmm[7];
	char	Old43[9];	/* record of 43..   register values	*/
	char	OldA0[9];	/* record of A0..A8 register values	*/
	char	OldB0[9];	/* record of B0..B8 register values	*/
	char	hmm2[16];	
	char	ToneSlideSpeed[9];	/* speed of tone slide		*/
	char	ToneSlideFreqL[9];	/* destination frequency of tone slide	*/
	char	ToneSlideFreqH[9];
	char	hmm3[11];
	char	ToneSlide[9];	/* tone slide flag			*/
	char	PortSlide[9];	/* portamento slide			*/
	char	VolSlide[9];	/* volume slide				*/

	char	ModSeg[2];		/* segment of module (starts at offset 0)*/
	char	Speed;		/* speed (n/50Hz) of tune		*/
	char	SpeedCnt;	/* counter used for deriving speed	*/

	char	OrderSize[2];	/* no. of entries in Order List			*/
	char	OrderList[2];	/* offset in module of Order List		*/
	char 	OrderPos[2];	/* current playing position in Order List 	*/

	char	PatternList[2];	/* offset of pattern offset table in module	*/
	char	PatternPos[2];	/* offset to current line in current pattern	*/
	char	Line;		/* current line being played (usually +1)	*/
};

